忠犬八公的故事 (豆瓣)
Description: 忠犬八公的故事电影简介和剧情介绍,忠犬八公的故事影评、图片、预告片、影讯、论坛、在线购票
Keywords: 忠犬八公的故事,Hachi: A Dog's Tale,忠犬八公的故事影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.12豆瓣电影Top250

# 忠犬八公的故事 Hachi: A Dog's Tale (2009)

更新描述或海报

导演: 拉斯·霍尔斯道姆
编剧: 斯蒂芬·P·林赛 / 新藤兼人
主演: 理查·基尔 / 萨拉·罗默尔 / 琼·艾伦 / 罗比·萨布莱特 / 艾瑞克·阿瓦利 / 田川洋行 / 杰森·亚历山大 / 罗伯特·卡普荣
类型: 剧情
制片国家/地区: 美国 / 英国
语言: 英语 / 日语
上映日期: 2009-06-13(西雅图电影节) / 2010-03-12(英国)
片长: 93分钟
又名: 秋田犬八千(港) / 忠犬小八(台) / 忠犬传奇
IMDb: tt1028532
豆瓣评分
引用
9.4
1339106人评价
5星
74.7%
4星
21.3%
3星
3.7%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
8.7
3人评价
好于 99% 剧情片
我看过这部电影 2020-08-04 修改
我的评价:
推荐

## 忠犬八公的故事的剧情简介 · · · · · ·

八公（Forest 饰）是一条谜一样的犬，因为没有人知道它从哪里来。教授帕克（理查·基尔 Richard Gere 饰）在小镇的火车站拣到一只走失的小狗，冥冥中似乎注定小狗和帕克教授有着某种缘分，帕克一抱起这只小狗就再也放不下来，最终，帕克对小狗八公的疼爱感化了起初极力反对养狗的妻子卡特（琼·艾伦 Joan Allen 饰）。八公在帕克的呵护下慢慢长大，帕克上班时八公会一直把他送到车站，下班时八公也会早早便爬在车站等候，八公的忠诚让小镇的人家对它更加疼爱。有一天，八公在帕克要上班时表现异常，居然玩起了以往从来不会的捡球游戏，八公的表现让帕克非常满意，可是就是在那天，帕克因病去世。帕克的妻子、女儿安迪（萨拉·罗默尔 Sarah Roemer 饰）及女婿迈克尔（罗比·萨布莱特 Robbie Sublett 饰）怀着无比沉痛的心情埋葬了帕克，可是不明就里的... (展开全部) 八公（Forest 饰）是一条谜一样的犬，因为没有人知道它从哪里来。教授帕克（理查·基尔 Richard Gere 饰）在小镇的火车站拣到一只走失的小狗，冥冥中似乎注定小狗和帕克教授有着某种缘分，帕克一抱起这只小狗就再也放不下来，最终，帕克对小狗八公的疼爱感化了起初极力反对养狗的妻子卡特（琼·艾伦 Joan Allen 饰）。八公在帕克的呵护下慢慢长大，帕克上班时八公会一直把他送到车站，下班时八公也会早早便爬在车站等候，八公的忠诚让小镇的人家对它更加疼爱。有一天，八公在帕克要上班时表现异常，居然玩起了以往从来不会的捡球游戏，八公的表现让帕克非常满意，可是就是在那天，帕克因病去世。帕克的妻子、女儿安迪（萨拉·罗默尔 Sarah Roemer 饰）及女婿迈克尔（罗比·萨布莱特 Robbie Sublett 饰）怀着无比沉痛的心情埋葬了帕克，可是不明就里的八公却依然每天傍晚五点准时守候在小站的门前，等待着主人归来……
本片根据上个世纪30年代发生在日本的真实故事改编，1987年在日本拍成电影后创造了40亿日元的票房。 ©豆瓣

## 忠犬八公的故事的演职员 · · · · · · ( 全部 32 )

- 拉斯·霍尔斯道姆 导演
- 理查·基尔 饰 Parker Wilson
- 萨拉·罗默尔 饰 Andy
- 琼·艾伦 饰 Cate Wilson
- 罗比·萨布莱特 饰 Michael
- 艾瑞克·阿瓦利 饰 Jasjeet

## 忠犬八公的故事的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片614 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  疯狂动物城

  忠犬八公物语

  迁徙的鸟

  一条狗的使命

  帝企鹅日记

  导盲犬小Q

  南极大冒险

  流浪猫鲍勃

  多哥

  狮子王

我要写短评

## 忠犬八公的故事的短评 · · · · · · ( 全部 295521 条 )

热门 / 最新 / 好友

### 9053 有用 malingcat 看过 2010-10-30 00:12:19

八公的主人，也在天堂的门口等了它很久吧。

### 7287 有用 汪拾叁 看过 2010-02-06 20:02:14

这真是漫长的一生啊，八公。

### 6271 有用 shu 看过 2010-02-14 23:07:02

Hachi就是爱一个人过一生了。

### 4764 有用 farmyra 看过 2010-02-05 14:36:08

动物是我的死穴...从头哭到尾..

### 4094 有用 神迦乐小舞 看过 2010-02-06 13:48:18

这是我所看过的关于狗狗电影最感人的一部，我想它的成功之处就在于将重点正确放至在了对Hachi内心的刻画上，而没有像其他一些影片文不对题，偏偏喜欢渲染一些多余人物的情感，很显然，主题对了，观影者自然而然会买单。

> 更多短评 295521条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 忠犬八公的故事的影评 · · · · · · ( 全部 4276 条 )

热门 / 最新 / 好友
暖言巷陌 2010-02-09 22:53:49

## 愿我如星君如月，夜夜流光相皎洁

水来我在水中等你，火来我在灰烬中等你。 ————洛夫 八（はち）、Hachiko，这是一个被爱注册过的名字。它的意思是延伸到天际又降落到大地。 【许你一世的欢颜】 它是一只狗。一只被他捡回来的小狗。它看起来一无所长。 倒叙、慢镜头、长镜头、对景深镜头的自然追求，一切温... (展开)
5149 206 344回应 收起
豆你玩 2010-02-08 21:50:40

## 因为做不到，所以被感动

为了一份爱等十年，对于狗来说已近一生。是什么让hachi如此执着，是在车站初见的寒夜里那抹温暖的微笑，还是之后数年如一日的悉心相伴。人生若只如初见，世上有几人能做到？ 为什么我们会被这样那样的事情感动，其根源在于我们自己做不到，向善向美的心，每个人都有，可是谁愿... (展开)
1845 78 173回应 收起
家有小白 2010-01-19 00:28:18

## 被 煽情

义犬八公的事迹听说已久，但即便如此，在把这张碟放进dvd的时候，我的心情依然是颇有些忐忑的。事实上，在对待一切以动物为主题的电影上，我向来谨慎。我就是受不了那些个悲惨兮兮的剧情，万一再加上导演一通连画面带音乐技巧纯熟的煽乎，每每遇到这种情况，泪腺大多就会不争气... (展开)
623 70 94回应 收起
谭小睡 2010-02-10 22:35:17

## 等你的十年，唯一的十年

你会为什么等十年？ 你知道吗，狗狗的世界只有黑白灰三种颜色。 你知道吗，小狗的视力极差，几乎看不见东西。 你知道吗，狗狗能记住熟悉的气味，一生不忘。 你知道吗，狗狗的寿命一般为12至15年。 你知道吗，成年的狗狗拥有相当于四岁孩子的智商。... (展开)
590 15 46回应 收起
vivien 2010-01-16 23:22:04

## 每一个狗狗，也许都是八公

近期看过的最感人的电影。 虽然在接到碟片的时候，同事已经打了预防针，说不要哭的太凶哦，最后眼泪还是噼里啪啦的落个不停。我总是对和动物有关的东西没有抵抗力。 这是一个真实的故事。每天的5点零5分，都会有一只乖狗狗，坐的笔直，在小城的车站门外等待主人的归来。有一... (展开)
350 27 103回应 收起
马哒 2010-02-27 01:20:39

## 要有多坚强，才敢念念不忘

这篇影评可能有剧透

这是一个真实的故事。每天早上五点零五分，总会有一只狗狗端坐在火车站门口，等它的主人。这只狗狗叫Hachiko，日语里的“八”，这是一个被爱注册过的名字。它的意思是延伸到天际又降落到大地。 我是一个正在养狗的人。养的是一只红色的小贵宾。它是妈妈抱回来的，每天妈妈出门... (展开)
297 8 50回应 收起
樱花飞舞时 2018-01-25 15:57:11

## 你是我一生的羁绊

这篇影评可能有剧透

因为你，我才有了家 因为你，我才有了温暖 因为你，我才有了存在的价值 有一天，我感觉你要走了 我学会了捡球，想要留住你 最后，你还是走了 我以为，你一定会回来的 所以，我一直在家等着你 我等了好久，你还是没有回来 我去你经常去的地方等你 人们跟我说，你不会回来了 真的... (展开)
181 18回应 收起
乔小囧 2010-07-06 02:31:31

## 我的一生，从与你相遇的那天便开始……

下午的时候，女友忽然打来电话，在电话里苦的稀里哗啦的。在电话里安慰了大约十分钟，才知道原来她是看了一个叫《忠犬八公的故事》的电影。晚上陪女友自习的时候一直在想，看一部动物片都能哭成这样，俩眼圈肿的跟鸡蛋似得，要么是看电影的人超级大傻逼要么电影超级大牛逼。我... (展开)
209 10 30回应 收起
九条命 2016-05-08 15:32:25

## 忠犬八公

因为一份爱 它等了十年 十年或许是人生命的百分之十 十年过后人可以重新开始 但对于它 却是一生一世 可它十年如一日 一直注视着那道门 等待着他的归来 也许它心里早已明白 他不可能会再回来 可它却不曾放弃 这是它的忠诚 它对他的爱 影片以 My Hero 开始 ... (展开)
82 5 5回应 收起

> 更多影评 4276篇

添加新讨论

## 讨论区 · · · · · ·

多年后补一条 | 来自壹个人哭 |  | 2022-11-22 21:22:26
我们习惯了别离还是被迫别离？ | 来自打酱油的小二 |  | 2022-11-21 18:17:27
忠犬八公是儿子说好看就看了，感觉不错！故事情节... | 来自燕子 |  | 2022-11-20 17:30:45
教授亲热之后，第二天走的。这意思是教授纵欲过度... | 来自好水告 | 5 回应 | 2022-11-19 14:40:50
教授的家里人就这样抛弃了八公？ | 来自野比大猫 | 1 回应 | 2022-11-19 14:37:53

> 去这部影片的讨论区（全部736条）

## 关于《忠犬八公的故事》的问题 · · · · · · ( 全部27个 )

- 人与人之间存在这样的忠诚吗？ 12人回答
- 从八公反映两国之间的关系？ 15人回答

> 全部27个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 极品电影 (waking forest)
- 【根据真实故事改编】 (影志)

## 谁在看这部电影 · · · · · ·

- Guofy
  刚刚 看过
- 果味小狗
  1分钟前 想看
- 峰峰
  1分钟前 想看

2646486人看过 / 370211人想看

订阅忠犬八公的故事的评论:
feed: rss 2.0